@@ -1,13 +1,18 @@
 """Cedrus make a variety of input devices. 
 See http://www.cedrus.com/
 
+DEPRECATED:
+This sub-package is out of date. Please use the cedrus-written
+pyxid package instead (bundled with Standalone PsychoPy)::
+    import pyxid
+    
 ----------
 """
 # Part of the PsychoPy library
-# Copyright (C) 2010 Jonathan Peirce
+# Copyright (C) 2012 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
-from psychopy import core, log
+from psychopy import core, logging
 import struct, sys
 
 try: import serial
