@@ -2,11 +2,11 @@
 - just handy things like conversion functions etc...
 """
 # Part of the PsychoPy library
-# Copyright (C) 2011 Jonathan Peirce
+# Copyright (C) 2012 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
 import numpy, random #this is imported by psychopy.core
-from psychopy import log
+from psychopy import logging
 import monitors
 
 import os, shutil
@@ -194,14 +194,13 @@ def makeImageAuto(inarray):
     return image2array(float_uint8(inarray))
 
 def image2array(im):
-    """Takes an image object (PIL) and returns an array
-
-     fredrik lundh, october 1998
-
-     fredrik@pythonware.com
-     http://www.pythonware.com
-
+    """Takes an image object (PIL) and returns a numpy array
     """
+#     fredrik lundh, october 1998
+#
+#     fredrik@pythonware.com
+#     http://www.pythonware.com
+
     if im.mode not in ("L", "F"):
             raise ValueError, "can only convert single-layer images"
     if im.mode == "L":
@@ -255,14 +254,14 @@ def float_uint16(inarray):
     return retVal.astype(numpy.UnsignedInt16)
 
 def sph2cart(*args):
-    #convert from spherical coordinates (elevation, azimuth, radius)
-    #to cartesian (x,y,z)
-
-    #usage:
-        #array3xN[x,y,z] = sph2cart(array3xN[el,az,rad])
-        #OR
-        #x,y,z = sph2cart(elev, azim, radius)
+    """Convert from spherical coordinates (elevation, azimuth, radius)
+    to cartesian (x,y,z)
 
+    usage:
+        array3xN[x,y,z] = sph2cart(array3xN[el,az,rad])
+        OR
+        x,y,z = sph2cart(elev, azim, radius)
+    """
     if len(args)==1:    #received an Nx3 array
         elev = args[0][0,:]
         azim = args[0][1,:]
@@ -358,16 +357,19 @@ def cm2pix(cm, monitor):
 
 #---color conversions---#000000#FFFFFF------------------------------------------
 def dkl2rgb(dkl_Nx3, conversionMatrix=None):
-    #Convert from DKL color space (cone-opponent space from Derrington,
-    #Krauskopf & Lennie) to RGB.
+    """Convert from DKL color space (cone-opponent space from Derrington,
+    Krauskopf & Lennie) to RGB.
 
-    #Requires a conversion matrix, which will be generated from generic
-    #Sony Trinitron phosphors if not supplied (note that this will not be
-    #an accurate representation of the color space unless you supply a
-    #conversion matrix
-    #
-    #usage:
-        #rgb(Nx3) = dkl2rgb(dkl_Nx3(el,az,radius), conversionMatrix)
+    Requires a conversion matrix, which will be generated from generic
+    Sony Trinitron phosphors if not supplied (note that this will not be
+    an accurate representation of the color space unless you supply a
+    conversion matrix).
+
+    usage::
+
+        rgb(Nx3) = dkl2rgb(dkl_Nx3(el,az,radius), conversionMatrix)
+
+    """
 
     dkl_3xN = numpy.transpose(dkl_Nx3)#its easier to use in the other orientation!
     if numpy.size(dkl_3xN)==3:
@@ -382,16 +384,17 @@ def dkl2rgb(dkl_Nx3, conversionMatrix=None):
             [1.0000, 1.0000, -0.1462],#R
             [1.0000, -0.3900, 0.2094],#G
             [1.0000, 0.0180, -1.0000]])#B
-        log.warning('This monitor has not been color-calibrated. Using default DKL conversion matrix.')
+        logging.warning('This monitor has not been color-calibrated. Using default DKL conversion matrix.')
 
     rgb = numpy.dot(conversionMatrix, dkl_cartesian)
 
     return numpy.transpose(rgb)#return in the shape we received it
 
 def dklCart2rgb(LUM, LM, S, conversionMatrix=None):
-    """Like dkl2rgb2D except that it uses cartesian coords (LM,S,LUM) rather than
+    """Like dkl2rgb except that it uses cartesian coords (LM,S,LUM) rather than
     spherical coords for DKL (elev, azim, contr)
-    NB: Due to the matrix multiplication, this may return rgb values >1 or <-1
+
+    NB: this may return rgb values >1 or <-1
     """
     NxNx3=list(LUM.shape)
     NxNx3.append(3)
@@ -407,7 +410,7 @@ def dklCart2rgb(LUM, LM, S, conversionMatrix=None):
     return numpy.reshape(numpy.transpose(rgb), NxNx3)
 
 def rgb2dklCart(picture, conversionMatrix=None):
-    """convert an RGB image into Cartesian DKL space"""
+    """Convert an RGB image into Cartesian DKL space"""
     #Turn the picture into an array so we can do maths
     picture=numpy.array(picture)
     #Find the original dimensions of the picture
@@ -420,7 +423,7 @@ def rgb2dklCart(picture, conversionMatrix=None):
             [ 0.25145542,  0.64933633,  0.09920825],
             [ 0.78737943, -0.55586618, -0.23151325],
             [ 0.26562825,  0.63933074, -0.90495899]])
-        log.warning('This monitor has not been color-calibrated. Using default DKL conversion matrix.')
+        logging.warning('This monitor has not been color-calibrated. Using default DKL conversion matrix.')
     else:
         conversionMatrix = numpy.linalg.inv(conversionMatrix)
 
@@ -439,15 +442,18 @@ def rgb2dklCart(picture, conversionMatrix=None):
     return dklPicture
 
 def lms2rgb(lms_Nx3, conversionMatrix=None):
-    #Convert from cone space (Long, Medium, Short) to RGB.
+    """Convert from cone space (Long, Medium, Short) to RGB.
 
-    #Requires a conversion matrix, which will be generated from generic
-    #Sony Trinitron phosphors if not supplied (note that you will not get
-    #an accurate representation of the color space unless you supply a
-    #conversion matrix)
-    #
-    #usage:
-        #rgb(Nx3) = lms2rgb(dkl_Nx3(el,az,radius), conversionMatrix)
+    Requires a conversion matrix, which will be generated from generic
+    Sony Trinitron phosphors if not supplied (note that you will not get
+    an accurate representation of the color space unless you supply a
+    conversion matrix)
+
+    usage::
+
+        rgb_Nx3 = lms2rgb(dkl_Nx3(el,az,radius), conversionMatrix)
+
+    """
 
     lms_3xN = numpy.transpose(lms_Nx3)#its easier to use in the other orientation!
 
@@ -458,18 +464,60 @@ def lms2rgb(lms_Nx3, conversionMatrix=None):
             [-0.90913894, 2.15671326, -0.24757432],#G
             [-0.03976551, -0.14253782, 1.18230333]#B
             ])
-        log.warning('This monitor has not been color-calibrated. Using default LMS conversion matrix.')
+        logging.warning('This monitor has not been color-calibrated. Using default LMS conversion matrix.')
     else: cones_to_rgb=conversionMatrix
 
     rgb_to_cones = numpy.linalg.pinv(cones_to_rgb)#get inverse
     rgb = numpy.dot(cones_to_rgb, lms_3xN)
     return numpy.transpose(rgb)#return in the shape we received it
 
+def hsv2rgb(hsv_Nx3):
+    """Convert from HSV color space to RGB gun values
+
+    usage::
+
+        rgb_Nx3 = hsv2rgb(hsv_Nx3)
+
+    Note that in some uses of HSV space the Hue component is given in radians or
+    cycles (range 0:1]). In this version H is given in degrees (0:360).
+    """
+    #based on method in http://en.wikipedia.org/wiki/HSL_and_HSV#Converting_to_RGB
+    hsv_Nx3 = numpy.asarray(hsv_Nx3, dtype=float)
+    H_ = (hsv_Nx3[:,0]%360)/60.0 #this is H' in the wikipedia version
+    C = hsv_Nx3[:,1]*hsv_Nx3[:,2] #multiply H and V to give chroma (color intensity)
+    X = C*(1-abs(H_%2-1))
+
+    #rgb starts
+    rgb=hsv_Nx3*0#only need to change things that are no longer zero
+    II = (0<=H_)*(H_<1)
+    rgb[II,0]=C[II]
+    rgb[II,1]=X[II]
+    II = (1<=H_)*(H_<2)
+    rgb[II,0]=X[II]
+    rgb[II,1]=C[II]
+    II = (2<=H_)*(H_<3)
+    rgb[II,1]=C[II]
+    rgb[II,2]=X[II]
+    II = (3<=H_)*(H_<4)
+    rgb[II,1]=X[II]
+    rgb[II,2]=C[II]
+    II = (4<=H_)*(H_<5)
+    rgb[II,0]=X[II]
+    rgb[II,2]=C[II]
+    II = (5<=H_)*(H_<6)
+    rgb[II,0]=C[II]
+    rgb[II,2]=X[II]
+    m=(hsv_Nx3[:,2] - C)
+    rgb +=  m.reshape([len(m),1])# V-C is sometimes called m
+    return rgb
+
 def pol2cart(theta, radius, units='deg'):
     """Convert from polar to cartesian coordinates
 
-    **usage**:
+    usage::
+
         x,y = pol2cart(theta, radius, units='deg')
+
     """
     if units in ['deg', 'degs']:
         theta = theta*numpy.pi/180.0
@@ -481,10 +529,12 @@ def pol2cart(theta, radius, units='deg'):
 def  cart2pol(x,y, units='deg'):
     """Convert from cartesian to polar coordinates
 
-    **usage**:
+    :usage:
+
         theta, radius = pol2cart(x, y, units='deg')
 
-    units refers to the units (rad or deg) for theta that should be returned"""
+    units refers to the units (rad or deg) for theta that should be returned
+    """
     radius= numpy.hypot(x,y)
     theta= numpy.arctan2(y,x)
     if units in ['deg', 'degs']:
@@ -494,15 +544,15 @@ def  cart2pol(x,y, units='deg'):
 def plotFrameIntervals(intervals):
     """Plot a histogram of the frame intervals.
 
-    Arguments:
-        - intervals: Either a filename to a log file, saved by Window.saveFrameIntervals
-            or simply a list (or array of frame intervals)
+    Where `intervals` is either a filename to a file, saved by Window.saveFrameIntervals
+    or simply a list (or array) of frame intervals
+
     """
     from pylab import hist, show, plot
 
     if type(intervals)==str:
         f = open(intervals, 'r')
         exec("intervals = [%s]" %(f.readline()))
-#    hist(intervals, int(len(intervals)/10))
+    #    hist(intervals, int(len(intervals)/10))
     plot(intervals)
     show()
